@@ -4,7 +4,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -13,8 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  * For more details see the file COPYING.
  */
@@ -26,6 +25,7 @@
 
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
+#include <libgames-support.h>
 
 #include "gbdefs.h"
 #include "gameconfig.h"
@@ -36,8 +36,6 @@
 #include "properties.h"
 #include "graphics.h"
 #include "cursors.h"
-#include "games-scores.h"
-#include "games-scores-dialog.h"
 
 /**********************************************************************/
 /* Exported Variables                                                 */
@@ -71,7 +69,7 @@ static gint temp_arena[GAME_WIDTH][GAME_HEIGHT];
 /* Function Prototypes                                                */
 /**********************************************************************/
 static void message_box (gchar * msg);
-static guint log_score (gint sc);
+static void log_score (gint sc);
 static void add_kill (gint type);
 static void clear_arena (void);
 static gint check_location (gint x, gint y);
@@ -93,6 +91,7 @@ static gboolean random_teleport (void);
 static gboolean safe_teleport (void);
 /**********************************************************************/
 
+GamesScoresCategory* current_cat;
 
 /**********************************************************************/
 /* Function Definitions                                               */
@@ -118,86 +117,29 @@ message_box (gchar * msg)
 
 /**
  * show_scores
- * @pos: score-table position
- * @endofgame: game state
  *
  * Description:
  * Displays the high-score table
  **/
 
-gint
-show_scores (gint pos, gboolean endofgame)
+void
+show_scores (void)
 {
-  gchar *message;
-  static GtkWidget *scoresdialog = NULL;
-  static GtkWidget *sorrydialog = NULL;
-  GtkWidget *dialog;
-  gint result;
+  games_scores_context_run_dialog (highscores);
+}
 
-  if (endofgame && (pos <= 0)) {
-    if (sorrydialog != NULL) {
-      gtk_window_present (GTK_WINDOW (sorrydialog));
-    } else {
-      sorrydialog = gtk_message_dialog_new_with_markup (GTK_WINDOW (window),
-                                                        GTK_DIALOG_DESTROY_WITH_PARENT,
-                                                        GTK_MESSAGE_INFO,
-                                                        GTK_BUTTONS_NONE,
-                                                        "<b>%s</b>\n%s",
-                                                        _
-                                                        ("Game over!"),
-                                                        _
-                                                        ("Great work, but unfortunately your score did not make the top ten."));
-      gtk_dialog_add_buttons (GTK_DIALOG (sorrydialog), _("_Quit"),
-                              GTK_RESPONSE_REJECT, _("_New Game"),
-                              GTK_RESPONSE_ACCEPT, NULL);
-      gtk_dialog_set_default_response (GTK_DIALOG (sorrydialog),
-                                       GTK_RESPONSE_ACCEPT);
-      gtk_window_set_title (GTK_WINDOW (sorrydialog), "");
-    }
-    dialog = sorrydialog;
-  } else {
+static void
+add_score_cb (GObject *source_object, GAsyncResult *res, gpointer user_data)
+{
+  GamesScoresContext *context = GAMES_SCORES_CONTEXT (source_object);
+  GError *error = NULL;
 
-    if (scoresdialog != NULL) {
-      gtk_window_present (GTK_WINDOW (scoresdialog));
-    } else {
-      scoresdialog = games_scores_dialog_new (GTK_WINDOW (window),
-                                        highscores, _("Robots Scores"));
-      games_scores_dialog_set_category_description (GAMES_SCORES_DIALOG
-                                                    (scoresdialog),
-                                                    _("Map:"));
-    }
+  games_scores_context_add_score_finish (context, res, &error);
 
-    if (pos > 0) {
-      play_sound (SOUND_VICTORY);
-
-      games_scores_dialog_set_hilight (GAMES_SCORES_DIALOG (scoresdialog),
-                                       pos);
-      message = g_strdup_printf ("<b>%s</b>\n\n%s",
-                                 _("Congratulations!"),
-                                 pos == 1 ? _("Your score is the best!") :
-                                 _("Your score has made the top ten."));
-      games_scores_dialog_set_message (GAMES_SCORES_DIALOG (scoresdialog),
-                                       message);
-      g_free (message);
-    } else {
-      games_scores_dialog_set_message (GAMES_SCORES_DIALOG (scoresdialog),
-                                       NULL);
-    }
-
-    if (endofgame) {
-      games_scores_dialog_set_buttons (GAMES_SCORES_DIALOG (scoresdialog),
-                                       GAMES_SCORES_QUIT_BUTTON |
-                                       GAMES_SCORES_NEW_GAME_BUTTON);
-    } else {
-      games_scores_dialog_set_buttons (GAMES_SCORES_DIALOG (scoresdialog), 0);
-    }
-    dialog = scoresdialog;
+  if (error != NULL) {
+    g_warning ("Failed to add score: %s", error->message);
+    g_error_free (error);
   }
-
-  result = gtk_dialog_run (GTK_DIALOG (dialog));
-  gtk_widget_hide (dialog);
-
-  return result;
 }
 
 /**
@@ -206,14 +148,10 @@ show_scores (gint pos, gboolean endofgame)
  *
  * Description:
  * Enters a score in the high-score table
- *
- * Returns:
- * the position in the high-score table
  **/
-static guint
+static void
 log_score (gint sc)
 {
-  guint pos = 0;
   gchar *sbuf = NULL;
 
   if (properties_super_safe_moves ()) {
@@ -230,12 +168,12 @@ log_score (gint sc)
   }
 
   if (sc != 0) {
-    games_scores_set_category (highscores, sbuf);
-    pos = games_scores_add_plain_score (highscores, (guint32) sc);
+    const gchar* key = sbuf;
+    const gchar* name = category_name_from_key (key);
+    current_cat = games_scores_category_new (key, name);
+    games_scores_context_add_score (highscores, (guint32) sc, current_cat, NULL, add_score_cb, NULL);
   }
   g_free (sbuf);
-
-  return pos;
 }
 
 /**
@@ -564,10 +502,7 @@ timeout_cb (void *data)
     ++endlev_counter;
     if (endlev_counter >= DEAD_DELAY) {
       if (score > 0) {
-        sp = log_score (score);
-        if (show_scores (sp, TRUE) == GTK_RESPONSE_REJECT) {
-          quit_game ();
-        }
+        log_score (score);
       }
       start_new_game ();
     }
