@@ -2,15 +2,14 @@
 #define GNOBOTS_H
 
 #include <gtk/gtk.h>
-
-#include "games-scores.h"
+#include <libgames-support.h>
 
 /**********************************************************************/
 /* Exported Variables                                                 */
 /**********************************************************************/
 extern GtkWidget *window;
 extern GtkWidget *game_area;
-extern GamesScores *highscores;
+extern GamesScoresContext *highscores;
 extern GSettings *settings;
 /**********************************************************************/
 
@@ -20,6 +19,7 @@ extern GSettings *settings;
 void set_move_action_sensitivity (gboolean state);
 void update_game_status (gint score, gint level, gint safe_teleports);
 void quit_game (void);
+const gchar* category_name_from_key (const gchar *);
 /**********************************************************************/
 
 #endif /* GNOBOTS_H */
