@@ -4,7 +4,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -13,8 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  * For more details see the file COPYING.
  */
@@ -26,6 +25,7 @@
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
+#include <libgames-support.h>
 
 #include "properties.h"
 #include "gameconfig.h"
@@ -36,8 +36,6 @@
 #include "game.h"
 #include "games-file-list.h"
 #include "games-controls.h"
-#include "games-scores.h"
-#include "games-scores-dialog.h"
 
 
 /**********************************************************************/
